@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2013 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2013 Balabit
  * Copyright (c) 1998-2013 Balázs Scheidler
  *
  * This library is free software; you can redistribute it and/or
@@ -28,6 +28,6 @@
 #include "filter-expr.h"
 
 FilterExprNode *filter_facility_new(guint32 facilities);
-FilterExprNode *filter_level_new(guint32 levels);
+FilterExprNode *filter_severity_new(guint32 levels);
 
 #endif
